==> haskell-versions-5.0.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-versions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 versions
version:              5.0.0
visibility:           public
id:                   versions-5.0.0-F75raJrW94rLw5v3hZtCCV
key:                  versions-5.0.0-F75raJrW94rLw5v3hZtCCV
license:              BSD-3-Clause
maintainer:           colin@fosskers.ca
author:               Colin Woodbury
homepage:             https://github.com/fosskers/versions
synopsis:             Types and parsers for software version numbers.
description:
    A library for parsing and comparing software version numbers. We like to give
    version numbers to our software in a myriad of ways. Some ways follow strict
    guidelines for incrementing and comparison. Some follow conventional wisdom
    and are generally self-consistent. Some are just plain asinine. This library
    provides a means of parsing and comparing /any/ style of versioning, be it a
    nice Semantic Version like this:

    > 1.2.3-r1+git123

    ...or a monstrosity like this:

    > 2:10.2+0.0093r3+1-1

    Please switch to <http://semver.org Semantic Versioning> if you aren'\''t
    currently using it. It provides consistency in version incrementing and has
    the best constraints on comparisons.

    This library implements version @2.0.0@ of the SemVer spec.

category:             Data
abi:                  0c1f659f339db5d5804077706445c22a
exposed:              True
exposed-modules:      Data.Versions
import-dirs:          /usr/lib/ghc-9.0.1/site-local/versions-5.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/versions-5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/versions-5.0.0
hs-libraries:         HSversions-5.0.0-F75raJrW94rLw5v3hZtCCV
depends:
    base-4.15.0.0 deepseq-1.4.5.0
    hashable-1.3.3.0-42gRc2xLctC1JaYfPjkrlX
    megaparsec-9.1.0-91xF1GIk5A1Gf8CCI5334q
    parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-versions/html/versions.haddock
haddock-html:         /usr/share/doc/haskell-versions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-versions-5.0.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-versions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 versions
version:              5.0.0
visibility:           public
id:                   versions-5.0.0-9bzXW3Ygc5v8y8xM76fTXs
key:                  versions-5.0.0-9bzXW3Ygc5v8y8xM76fTXs
license:              BSD-3-Clause
maintainer:           colin@fosskers.ca
author:               Colin Woodbury
homepage:             https://github.com/fosskers/versions
synopsis:             Types and parsers for software version numbers.
description:
    A library for parsing and comparing software version numbers. We like to give
    version numbers to our software in a myriad of ways. Some ways follow strict
    guidelines for incrementing and comparison. Some follow conventional wisdom
    and are generally self-consistent. Some are just plain asinine. This library
    provides a means of parsing and comparing /any/ style of versioning, be it a
    nice Semantic Version like this:

    > 1.2.3-r1+git123

    ...or a monstrosity like this:

    > 2:10.2+0.0093r3+1-1

    Please switch to <http://semver.org Semantic Versioning> if you aren'\''t
    currently using it. It provides consistency in version incrementing and has
    the best constraints on comparisons.

    This library implements version @2.0.0@ of the SemVer spec.

category:             Data
abi:                  2347b36b346cb9c509a789d4b01105fa
exposed:              True
exposed-modules:      Data.Versions
import-dirs:          /usr/lib/ghc-9.0.1/site-local/versions-5.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/versions-5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/versions-5.0.0
hs-libraries:         HSversions-5.0.0-9bzXW3Ygc5v8y8xM76fTXs
depends:
    base-4.15.0.0 deepseq-1.4.5.0
    hashable-1.3.3.0-LgC2GKp34OLEabneGtyuCb
    megaparsec-9.1.0-3baosRTM6G61cXADCCGeP9
    parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-versions/html/versions.haddock
haddock-html:         /usr/share/doc/haskell-versions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
